The (beta, beta) block of the inverse joint precision, so it includes the
uncertainty in the smoothing parameters rather than conditioning on them
(mgcv's unconditional = TRUE). Needs a fit made with
joint_precision = TRUE, which is the default.
Usage
# S3 method for class 'gamRTMB'
vcov(object, ...)